yahoo-finance-api
=============

Python module to get stock data from Yahoo! Finance

From pypi:

    pip3 install yahoo-finance-api

From repo:

    $ git clone git://github.com/rakeshbhat9/yahoo-finance-api.git

Usage examples
--------------
Detailed examples covered in example.ipynb

Available Functions
--------------

- ``get_historic_data()``
- ``get_most_active_stocks()``
- ``get_percent_change()``
- ``get_upcoming_earnings_data()``
- ``get_upcoming_stock_splits_data()``
- ``plot_ma()``
